* TITLE: Social Position and Fairness Views on Inequality
* AUTHORS: Kristoffer Balle Hvidberg, Claus Thustrup Kreiner, and Stefanie Stantcheva


********************************************************************************

	clear all
	set more off

********************************************************************************

* GLOBALS

	global data 		"I:\Workdata\707208\KBH\data"
	global figs 		"I:\Workdata\707208\KBH\output\fig"
	global tabs 		"I:\Workdata\707208\KBH\output\tab"
	global layout 		"graphregion(color(white)) plotregion(lc(black) lp(solid)) scheme(s2mono)"
	global postfiles	"I:\Workdata\707208\KBH\data\temp\postfiles"
	
********************************************************************************

* LOAD DATA

	cap frame create analysisI
	frame change analysisI 
	use "$data/analysisI", clear
	
	cap frame create analysisII
	frame change analysisII 
	use "$data/analysisII", clear

********************************************************************************

* PROGRAMS

	* Define a program posts number of observation and share treated as columns in the shock tables
	* Used for Table 5
	cap program drop Nshare
	program define Nshare
		mat X = J(1,1,.)
		mat Y = J(1,1,.)
		mat colnames X = `1'
		mat colnames Y = `1'
		mat X[1,1]=r(N)
		mat Y[1,1]=r(mean)*100
		ereturn post X
		eststo obs
		ereturn post Y
		eststo sha
	end
		
	* Path to ADO files
	* The folder contains _dstpctile.ado which calculates percentiles using 5 observations to comply with Statistics Denmark's rules. 
	adopath + "H:\CAM_info\Utilities\Pseudopercentiles\Stata"
	
	* Multiply estimates by 100
	cap program drop times100
	program define times100, eclass
		mat b = e(b)*100
		mat V = e(V)*100^2
		ereturn repost b=b V=V
	end

********************************************************************************					
							
* TABLE 1

	frame change analysisII

	label var male 				"\hspace{10pt}Male (\%)" 	
	label var married 			"\hspace{10pt}Married (\%)"
	label var immigrant 		"\hspace{10pt}Immigrant (\%)"
	label var descendant 		"\hspace{10pt}Descendant (\%)"
	label var age	 			"\hspace{10pt}Age"
	label var bottom_50 		"\hspace{10pt}Bottom 50\% (\%)"
	label var middle_40 		"\hspace{10pt}Middle 40\% (\%)"
	label var top_10 			"\hspace{10pt}Top 10\% (\%)"
	label var grundskole 		"\hspace{10pt}Primary education (\%)"
	label var erhv_udd 			"\hspace{10pt}Vocational education (\%)"
	label var gym_udd 			"\hspace{10pt}Upper secondary edu. (\%)"
	label var KVU 				"\hspace{10pt}Short cycle higher edu. (\%)"
	label var MVU 				"\hspace{10pt}Bachelor's programs (\%)"
	label var LVU 				"\hspace{10pt}Master's programs (\%)"
	label var hovedstaden 		"\hspace{10pt}Copenhagen (\%)"
	label var sjaelland 		"\hspace{10pt}Sealand (\%)" 
	label var syddanmark 		"\hspace{10pt}Southern Denmark (\%)"
	label var midtjylland 		"\hspace{10pt}Middle Jutland (\%)"
	label var nordjylland 		"\hspace{10pt}North Jutland (\%)"
	label var private_sector	"\hspace{10pt}Private sector (\%)"
	label var position_mother 	"\hspace{10pt}Mother's income position"
	label var position_father	"\hspace{10pt}Father's income position"
	label var inc_position 		"\hspace{10pt}Income position"
	label var self_employed 	"\hspace{10pt}Self-employed (\%)"
	label var employee 	  		"\hspace{10pt}Employee (\%)"
	label var unemployed 	  	"\hspace{10pt}Unemployed (\%)"
    label var not_workforce		"\hspace{10pt}Not in work force (\%)"

	eststo clear 
	local vars "male age married descendant inc_position bottom_50 middle_40 top_10 grundskole gym_udd erhv_udd KVU MVU LVU self_employed employee unemployed not_workforce private_sector hovedstaden sjaelland syddanmark midtjylland nordjylland position_mother position_father" 

	* Completed
	mat b = J(1,26,.)
	mat coln b = `vars'
	local i 0
	foreach x in `vars' {
		local ++i
		qui reg `x' if analysis == 1
		mat b[1,`i']=_b[_cons]
	}
	foreach x in 1 3 4 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 {
		mat b[1,`x']=b[1,`x']*100

	}
	count if analysis==1
	ereturn post b, obs(`r(N)')
	eststo completed
	
	* Invited
	mat b = J(1,26,.)
	mat coln b = `vars'
	local i 0
	foreach x in `vars' {
		local ++i
		qui reg `x' if invited == 1
		mat b[1,`i']=_b[_cons]
	}
	foreach x in 1 3 4 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 {
		mat b[1,`x']=b[1,`x']*100

	}
	count if invited==1
	ereturn post b, obs(`r(N)')
	eststo invited
	
	* Difference and P-value
	mat d = J(1,26,.)
	mat coln d = `vars'
	mat p = J(1,26,.)
	mat coln p = `vars'
	local i 0
	foreach x in `vars' {
		local ++i
		qui reg `x' analysis if invited == 1, robust
		mat d[1,`i']=_b[analysis]
		mat T = r(table)
		mat p[1,`i']=T[4,1]
	}
	foreach x in 1 3 4 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 {
		mat d[1,`x']=d[1,`x']*100

	}
	ereturn post d
	eststo difference
	forval x=1/26 {
		mat p[1,`x']=p[1,`x']*100
	}
	ereturn post p
	eststo p_value
	
	esttab completed invited p_value using "$tabs\Table1.tex", replace ///
	label b(1) nose nogap nomtit nonote ///
	mgroup("\textbf{Sample}" "\textbf{Invited}" "\textbf{P-value (\%)}", pattern(1 1 1) span) ///
	refcat(male "\textbf{Demographics}" inc_position "[1em]\textbf{Income Position}" grundskole "[1em]\textbf{Education}" self_employed "[1em]\textbf{Socioeconomic Status}" hovedstaden "[1em]\textbf{Regions}"  position_mother "[1em]\textbf{Parents' Income}" , nolabel) 

* NUMBERS IN TEXT: 1.2 Survey Outline

	frame change analysisI
	tab Q42 // 1: Right biased, 2 left biased, 3 neutral. 
	
* NUMBERS IN TEXT: Footnote 6

	cap drop temp
	gen temp = inc_reg/perindkialt_13
	sum temp, d
							
* FIGURE 2

	* Panel A
	cap postclose bar
	postfile bar x y1 y2 y3 refgrp grp using "$postfiles\bar", replace
	
	local if "if T==0"
	
	* Cohort
	reg Q37_coh `if', robust
	post bar (1) (_b[_cons]) (_b[_cons]+1.96*_se[_cons]) (_b[_cons]-1.96*_se[_cons]) (0) (99)
	
	* Gender
	reg Q37_sex `if', robust
	post bar (3) (_b[_cons]) (_b[_cons]+1.96*_se[_cons]) (_b[_cons]-1.96*_se[_cons]) (1) (99)
	
	* Municipality
	reg Q37_mun `if', robust
	post bar (5) (_b[_cons]) (_b[_cons]+1.96*_se[_cons]) (_b[_cons]-1.96*_se[_cons]) (2) (99)
	
	* Education
	reg Q37_edu `if', robust
	post bar (7) (_b[_cons]) (_b[_cons]+1.96*_se[_cons]) (_b[_cons]-1.96*_se[_cons]) (3) (99)
	
	* Sector
	reg Q37_sec `if', robust
	post bar (9) (_b[_cons]) (_b[_cons]+1.96*_se[_cons]) (_b[_cons]-1.96*_se[_cons]) (4) (99)
	
	cap postclose bar
	
	preserve
	
		use "$postfiles\bar", clear
		
		graph twoway	(bar y1 x if refgrp==0 & grp==99, col(black*0.75)) ///
						(bar y1 x if refgrp==1 & grp==99, col(cranberry*0.75)) ///
						(bar y1 x if refgrp==2 & grp==99, col(navy*0.75)) ///
						(bar y1 x if refgrp==3 & grp==99, col(green*0.75)) ///
						(bar y1 x if refgrp==4 & grp==99, col(purple*0.75)) ///
						(rcap y2 y3 x, col(black)), ///
						$layout xsize(20) ysize(20) ///
						xtitle("Reference groups") ///
						ytitle("Unfairness of inequality within group") ///
						xlabel(1 "Cohort" 3 "Gender" 5 "Municipality" 7 "Education" 9 "Sector", labsize(small)) ///
						ylabel(1(0.5)3, labsize(small) nogrid) ///
						legend(off) 
		
	restore
		
	graph export "$figs/Figure2A.pdf", replace

	* Panel B
	local if "if T==0"
	count `if'
	local bw "20"
	twoway 	(lpoly Q37_coh position_coh_reg     `if', deg(1) bw(`bw') lp(solid) 	lc(black))		///
			(lpoly Q37_sex position_sex_reg     `if', deg(1) bw(`bw') lp(dash)  	lc(cranberry))	///
			(lpoly Q37_mun position_per_mun_reg `if', deg(1) bw(`bw') lp(longdash)  lc(navy))		///
			(lpoly Q37_edu position_per_edu_reg `if', deg(1) bw(`bw') lp(shortdash) lc(green))		///
			(lpoly Q37_sec position_per_sec_reg `if', deg(1) bw(`bw') lp(dash_dot)  lc(purple)),	///
				$layout xsize(20) ysize(20) 									///
				xmtick(0(10)100) 												/// 
				xtitle("Actual position within reference group") 						///
				ytitle("Unfairness within reference group") 							///
				xlabel(, labsize(small)) ylabel(1(0.5)3.5, labsize(small) nogrid) 		///
				legend( 														///
					label(1 "Cohort") 											///
					label(2 "Gender") 												///
					label(3 "Municipality") 									///
					label(4 "Education") 										///
					label(5 "Sector") 											///
					r(5) ring(0) pos(7) bmargin(medium) size(small) 			///
				) 
				
	graph export "$figs/Figure2B.pdf", replace	

	* Panel C
	local if "if T==0"
	count `if'
	local bw "20"
	twoway 	(lpoly Q37_coh position_coh_reg `if', deg(1) bw(`bw') lp(solid) 	lc(black))		/// 
			(lpoly Q37_sex position_coh_reg `if', deg(1) bw(`bw') lp(dash)  	lc(cranberry))	///
			(lpoly Q37_mun position_coh_reg `if', deg(1) bw(`bw') lp(longdash)  lc(navy))		///
			(lpoly Q37_edu position_coh_reg `if', deg(1) bw(`bw') lp(shortdash) lc(green))		///
			(lpoly Q37_sec position_coh_reg `if', deg(1) bw(`bw') lp(dash_dot)  lc(purple)),	///
				$layout xsize(20) ysize(20) 									///
				xmtick(0(10)100) 												/// 
				xtitle("Actual position within cohort") 						///
				ytitle("Unfairness within reference group") 							///
				xlabel(, labsize(small)) ylabel(1(0.5)3.5, labsize(small) nogrid) 		///
				legend( 														///
					label(1 "Cohort") 											///
					label(2 "Gender") 												///
					label(3 "Municipality") 									///
					label(4 "Education") 										///
					label(5 "Sector") 											///
					r(5) ring(0) pos(7) bmargin(medium) size(small) 			///
				) 
				
	graph export "$figs/Figure2C.pdf", replace
		
	* Panel D
	local if "if T==0"
	count `if'
	local bw "20"
	twoway 	(lpoly Q38_coh position_coh_reg     `if', deg(1) bw(`bw') lp(solid) 	 lc(black))		///
			(lpoly Q38_sex position_sex_reg     `if', deg(1) bw(`bw') lp(dash)  	lc(cranberry))	///
			(lpoly Q38_mun position_per_mun_reg `if', deg(1) bw(`bw') lp(longdash)  lc(navy))		///
			(lpoly Q38_edu position_per_edu_reg `if', deg(1) bw(`bw') lp(shortdash) lc(green))		///
			(lpoly Q38_sec position_per_sec_reg `if', deg(1) bw(`bw') lp(dash_dot)  lc(purple)),	///
				$layout xsize(20) ysize(20) 									///
				xmtick(0(10)100) 												/// 
				xtitle("Actual position within reference group") 						///
				ytitle("Importance of effort  within reference group") 							///
				xlabel(, labsize(small)) ylabel(3.5(0.5)6, labsize(small) nogrid) 		///
				legend( 														///
					label(1 "Cohort") 											///
					label(2 "Gender") 												///
					label(3 "Municipality") 									///
					label(4 "Education") 										///
					label(5 "Sector") 											///
					r(5) ring(0) pos(5) bmargin(medium) size(small) 			///
				) 
				
	graph export "$figs/Figure2D.pdf", replace
	
* NUMBERS IN TEXT: 2.2 Evidence on fairness... 

	sum Q37_edu if T==0
	sum Q37_sec if T==0
	sum Q37_coh if T==0, d
		
* NUMBERS IN TEXT: Footnote 12

	* Test
	cap drop original
	expand 5, gen(original)
	sort pnr original
	cap drop n
	gen n=1 if pnr!=pnr[_n-1]
	replace n=n[_n-1]+1 if pnr==pnr[_n-1]
	cap drop temp_Q37
	gen 	temp_Q37 = .
	replace temp_Q37 = Q37_coh if n==1
	replace temp_Q37 = Q37_sex if n==2
	replace temp_Q37 = Q37_mun if n==3
	replace temp_Q37 = Q37_edu if n==4
	replace temp_Q37 = Q37_sec if n==5
	cap drop temp_position_reg 
	gen 	temp_position_reg = .
	replace temp_position_reg = position_coh_reg 	 if n==1
	replace temp_position_reg = position_sex_reg 	 if n==2
	replace temp_position_reg = position_per_mun_reg if n==3
	replace temp_position_reg = position_per_edu_reg if n==4
	replace temp_position_reg = position_per_sec_reg if n==5
	replace temp_position_reg = temp_position_reg-50
	reg	temp_Q37 i.n##c.temp_position_reg, vce(cluster pnr)	
	keep if original==0
	drop original

* NUMBERS IN TEXT: Footnote 13

	* Test 
	reg Q38_coh position_coh_reg, robust

* FIGURE 3
	
	cap drop bin1
	cap drop bin2
	cap drop bin3
	xtile bin1 = position_coh_reg,    n(25)
	xtile bin2 = position_coh_repinc, n(25)
	xtile bin3 = position_2015_2017,  n(25)
	
	cap postclose binscat 
	postfile binscat x y1 y2 y3 y4 y5 y6 se cat using "$postfiles\binscat.dta", replace
	forval x = 1/25 { 
		sum position_coh_reg     if bin1==`x', meanonly
		local p=r(mean)
		qui reg position_coh_sur if bin1==`x', robust
		local mean = _b[_cons]
		local se   = _se[_cons]
		_dstpctile position_coh_sur if bin1==`x', percentiles(10 25 50 75 90)
		local p10 = r(r1)
		local p25 = r(r2)
		local p50 = r(r3)
		local p75 = r(r4)
		local p90 = r(r5)
		
		post binscat (`p') (`mean') (`p50') (`p25') (`p75') (`p10') (`p90') (`se') (1)
	}
	postclose binscat 

	preserve
		use "$postfiles\binscat.dta", clear
		gen 	l=1   if _n==1
		replace l=100 if _n==2
		twoway	(line l l, lc(gs10) lp(dash)) ///
				(scatter y1 x if cat==1, mc(cranberry) ms(o)) ///
				(scatter y2 x if cat==1, mc(navy) ms(oh)), ///
				$layout xsize(20) ysize(20)  ///
				ylabel(0(20)100, nogrid labsize(small)) xlabel(, labsize(small)) ///
				xtitle("Actual position") ytitle("Perceived position") ///
				legend(order(2 3) label(2 "Average") label(3 "Median") r(3) ring(0) pos(5)) ///
				xmtick(0(10)100) ymtick(0(10)100) 
	restore
	
	graph export "$figs\Figure3.pdf", replace 
	graph close	
	
* FIGURE 4

	* Panel A
	cap drop bin
	local n_bins = 25
	xtile bin = inc_reg, nq(`n_bins')
	postfile binscat reg avg med p25 p75 count using "$postfiles\binscat.dta", replace
	forval x = 1/`n_bins'  { 
		qui sum inc_reg if bin==`x', meanonly
		loc avg_no = r(mean)
		qui sum inc_sur if bin==`x', d
		local mean = r(mean)
		local n = r(N)
		_dstpctile inc_sur if bin==`x', percentile(25 50 75)
		post binscat (`avg_no') (`mean') (r(r2)) (r(r1)) (r(r3)) (`n')
	}
	postclose binscat 
	
	preserve
		use "$postfiles\binscat.dta", clear
		gen axis=0 if _n==1
		local max = 1200000
		replace axis=`max' if _n==2
		twoway	(line axis axis, lc(gs10) lp(dash)) ///
				(scatter med reg if reg<`max', mc(navy) ms(oh)) ///
				(scatter avg reg if reg<`max', mc(cranberry) ms(o)), ///
				$layout xsize(20) ysize(20)  ///
				ylabel(0 "0" 300000 "300" 600000 "600" 900000 "900" 1200000 "1200", nogrid labsize(small)) xlabel(0 "0" 300000 "300" 600000 "600" 900000 "900" 1200000 "1200", labsize(small)) ///
				xtitle("Actual income (1000 DKK)") ytitle("Reported income (1000 DKK)") ///
				legend(r(2) label(2 "Median") label(3 "Average") pos(11) ring(0) order(3 2) bmargin(medium) size(small)) ///
				xmtick(0(100000)`max') ymtick(0(100000)`max') 
	restore
	
	graph export "$figs\Figure4A.pdf",  replace 
	graph close	
	
	* Panel B
	cap drop bin
	xtile bin = position_coh_reg,    n(10)
	cap postclose binscat 
	postfile binscat x y1 y2 y3 y4 cat using "$postfiles\binscat.dta", replace
	forval x = 1/10 { 
		
		sum position_coh_reg     if bin==`x', meanonly
		local p=r(mean)
		_dstpctile position_coh_sur if bin==`x' & (inc_rel<-5 | inc_rel>5), percentile(25 50 75)
		local mean = r(mean)
		local p25 = r(r1)
		local p50 = r(r2)
		local p75 = r(r3)
		post binscat (`p') (`mean') (`p50') (`p25') (`p75') (1)
		
		sum position_coh_reg     if bin==`x', meanonly
		local p=r(mean)
		_dstpctile position_coh_sur if bin==`x' & inrange(inc_rel,-5,5), percentile(25 50 75)
		local mean = r(mean)
		local p25 = r(r1)
		local p50 = r(r2)
		local p75 = r(r3)
		post binscat (`p') (`mean') (`p50') (`p25') (`p75') (2)
		
	}
	postclose binscat 
	
	preserve
		use "$postfiles\binscat.dta", clear
		gen 	l=1   if _n==1
		replace l=100 if _n==2
		
		replace x=x-1 if cat==1
		replace x=x+1 if cat==2
		
		twoway	(line l l, lc(gs10) lp(dash)) ///
				(scatter y2    x if cat==1, mc(navy) ms(sh)) ///
				(rspike  y3 y4 x if cat==1, lc(navy)) ///
				(scatter y2    x if cat==2, mc(cranberry) ms(th)) ///
				(rspike  y3 y4 x if cat==2, lc(cranberry)), ///
				$layout xsize(20) ysize(20)  ///
				ylabel(0(20)100, nogrid labsize(small)) xlabel(, labsize(small)) ///
				xtitle("Actual position") ytitle("Perceived position") ///
				legend(order(2 4) ///
					label(2 "Reports own income imprecisely") ///
					label(4 "Reports own income precisely") ///
					r(4) ring(0) pos(5) bmargin(medium) size(small)) ///
				xmtick(0(10)100) ymtick(0(10)100) 
	restore
	
	graph export "$figs\Figure4B.pdf",  replace 
	graph close		

* FIGURE 5

	* Panel A
	kdensity             p50_coh_r if (p50_coh_r<=100 & p50_coh_r>=-100), bw(10) lp(longdash)  lc(cranberry) lw(0.5)  ///
		addplot(kdensity inc_rel   if (inc_rel  <=100 & inc_rel  >=-100), bw(5)  lp(solid)     lc(black)     		  ///
			  ||kdensity p95_coh_r if (p95_coh_r<=100 & p95_coh_r>=-100), bw(15) lp(shortdash) lc(navy)      lw(0.5)) ///
			$layout xsize(20) ysize(20)  ///
			legend(r(3) label(1 "Level of P50") label(2 "Own income") label(3 "Level of P95")  pos(11) ring(0) order(1 3 2) bmargin(medium) size(small) symx(*0.75)) ///
			xtitle("Pct. difference between reported and actual level") ///
			ylabel(0(.01).05, nogrid labsize(small)) xlabel(, labsize(small)) ///
			title("") note("")
			
	graph export "$figs\Figure5A.pdf", replace
			
	* Panel B
	cap drop bin
	cap drop temp
	gen 	temp=p50_coh_sur
	replace temp=temp/1000
	local n_bins = 25
	xtile bin = position_coh_reg, nq(`n_bins')
	postfile binscat reg avg med p25 p75 count poly using "$postfiles\binscat.dta", replace
	forval x = 1/`n_bins'  { 
		_pctile temp 		     if bin==`x', n(100)
		replace temp=r(r95)      if bin==`x' & temp>r(r95) & !mi(temp)
		replace temp=r(r5)       if bin==`x' & temp<r(r5)
		qui sum position_coh_reg if bin==`x', meanonly
			loc avg_no = r(mean)
		qui sum temp             if bin==`x'
		local mean = r(mean)
		local n = r(N)
		_dstpctile temp          if bin==`x', percentiles(25 50 75)
		post binscat (`avg_no') (`mean') (r(r2)) (r(r1)) (r(r3)) (`n') (.)
	}
	cap drop poly
	cap drop n
	gen n=_n if _n<101
	lpoly temp position_coh_reg, deg(1) bw(20) generate(poly) at(n) nograph
	forval x = 1/100  { 
		qui sum poly if n==`x', meanonly
		post binscat (`x') (.) (.) (.) (.) (.) (r(mean))
	}
	postclose binscat 
	
	preserve
		use "$postfiles\binscat.dta", clear
		gen 	a=0   if _n==1
		replace a=100 if _n==2
		gen 	b=377.000 // Highest P50 across cohorts is 377000. Lowest is 373000. Based on the percentiles used in the survey (avg. over 5 obs. rounded to 1000).
		twoway	(area b a, base(373.000) col(gs12) yaxis(1 2)) ///
				(scatter avg reg, m(O) mc(cranberry) yaxis(1 2)) ///
				(scatter med reg, m(Oh) mc(navy) yaxis(1 2)) ///
				(line poly reg, lp(solid) lc(cranberry)) , ///
				$layout xsize(20) ysize(20)  ///
				ylabel(200(50)550, nogrid labsize(small) axis(1)) ///
				ylabel(187.500 "-50" 281.250 "-25" 375.000 "0" 468.750 "25" 562.500 "50", labsize(small) axis(2)) ///
				xlabel(0(20)100, labsize(small)) ///
				xtitle("Actual cohort position") ///
				ytitle("Reported cohort P50 (1000 DKK)", axis(1)) ///
				ytitle("Difference in percent from actual P50", axis(2)) ///
				legend(order(2 3) label(2 "Average") label(3 "Median") r(2) pos(11) ring(0) bmargin(medium) size(small)) ///
				xmtick(0(10)100) 
	restore
	
	graph export "$figs\Figure5B.pdf", 	 replace 
	
	* Slope reported in table notes
	reg temp position_coh_reg, robust
	
	* Panel C
	cap drop bin
	cap drop temp
	gen 	temp=p95_coh_sur
	replace temp=temp/1000
	local n_bins = 25
	xtile bin = position_coh_reg, nq(`n_bins')
	postfile binscat reg avg med p25 p75 count poly using "$postfiles\binscat.dta", replace
	forval x = 1/`n_bins'  { 
		_pctile temp 		     if bin==`x', n(100)
		replace temp=r(r95)      if bin==`x' & temp>r(r95) & !mi(temp)
		replace temp=r(r5)       if bin==`x' & temp<r(r5)
		qui sum position_coh_reg if bin==`x', meanonly
			loc avg_no = r(mean)
		qui sum temp             if bin==`x'
		local mean = r(mean)
		local n = r(N)
		_dstpctile temp          if bin==`x', percentiles(25 50 75)
		post binscat (`avg_no') (`mean') (r(r2)) (r(r1)) (r(r3)) (`n') (.)
	}
	cap drop poly
	cap drop n
	gen n=_n if _n<101
	lpoly temp position_coh_reg, deg(1) bw(20) generate(poly) at(n) nograph
	forval x = 1/100  { 
		qui sum poly if n==`x', meanonly
		post binscat (`x') (.) (.) (.) (.) (.) (r(mean))
	}
	postclose binscat 
	
	preserve
		use "$postfiles\binscat.dta", clear
		gen 	a=0   if _n==1
		replace a=100 if _n==2
		gen 	b=887.000 // Highest P95 across cohorts is 887000. Lowest is 856000. Based on the percentiles used in the survey (avg. over 5 obs. rounded to 1000).
		twoway	(area b a, base(856.000) col(gs12) yaxis(1 2)) ///
				(scatter avg reg, m(O) mc(cranberry) yaxis(1 2)) ///
				(scatter med reg, m(Oh) mc(navy) yaxis(1 2)) ///
				(line poly reg, lp(solid) lc(cranberry)), ///
				$layout xsize(20) ysize(20)  ///
				ylabel(400(200)1400, nogrid labsize(small) axis(1)) ///
				ylabel(438.500 "-50" 657.750 "-25" 877.000 "0" 1096.250 "25" 1315.500 "50", labsize(small) axis(2)) ///
				xlabel(0(20)100, labsize(small)) ///
				xtitle("Actual cohort position") ///
				ytitle("Reported cohort P95 (1000 DKK)", axis(1)) ///
				ytitle("Difference in percent from actual P95", axis(2)) ///
				legend(order(2 3) label(2 "Average") label(3 "Median") r(2)  pos(11) ring(0) bmargin(medium) size(small)) ///
				xmtick(0(10)100) 
	restore
	
	graph export "$figs\Figure5C.pdf", replace 
	graph close
	
	* Slope reported in table notes
	reg temp position_coh_reg, robust
	
* NUMBERS IN TEXT: 3.1, Perceptions of the income distribution
	
	count 
	local tot = r(N)
	count if inrange(inc_rel,-10,10)
	di r(N)/`tot'
	count if inrange(p50_coh_r,-10,10)
	di r(N)/`tot'
	di r(N)/`tot'
	count if inrange(inc_rel,-25,25)
	di r(N)/`tot'
	count if inrange(p50_coh_r,-25,25)
	di r(N)/`tot'
	
* NUMBERS IN TEXT: Footnote 17

	sum position_coh_reg if inc_reg==350000
	sum position_coh_reg if inc_reg==400000

* FIGURE 6

	* Add a small random number between -1 and 1 to actual P50/P95. This is important for generating 10 equally sized groups for municipality due to many respondents from the same large municipalities. 
	sort pnr
	set seed 1702
	cap drop rand 
	gen rand = runiform(-1,1)
	
	foreach m in 50 95 {
		
		* Level of winsorizing
		local p = `m'
		local w1 = 5
		local w2 = 100-`w1'
			
		* Postfiles
		cap postclose binscat	
		postfile binscat x y1 y2 se c using "$postfiles\binscat.dta", replace	
		
		local i 0
		foreach ref in coh sex mun edu sec {
			
			local ++i
			
			cap drop temp_reg
			cap drop temp_sur
			gen temp_reg = (p`p'_per_`ref'_reg + rand)/1000
			gen temp_sur =  p`p'_`ref'_sur/1000
			
			if `i'==1 { // cohort
				cap drop bin
				gen bin=1
				_pctile temp_sur, nq(100)
				replace temp_sur=r(r`w1') if temp_sur<r(r`w1')
				replace temp_sur=r(r`w2') if temp_sur>r(r`w2') & !mi(temp_sur)
				sum temp_reg if bin==1, meanonly	
				local x = r(mean)
				qui reg temp_sur if bin==1, robust
				local y1 = _b[_cons]
				local se = _se[_cons]
				_dstpctile temp_sur if bin==1, percentiles(50) 
				local y2 = r(r1)
				post binscat (`x') (`y1') (`y2') (`se') (`i')
				
			}
			if `i'==2 { // gender
				forval b=0/1 {
					local if "sex_reg==`b'"
					_pctile temp_sur if `if', nq(100)
					replace temp_sur=r(r`w1') if `if' & temp_sur<r(r`w1')
					replace temp_sur=r(r`w2') if `if' & temp_sur>r(r`w2') & !mi(temp_sur)
					sum temp_reg if `if', meanonly	
					local x = r(mean)
					qui reg temp_sur if `if', robust
					local y1 = _b[_cons]
					local se = _se[_cons]
					_dstpctile temp_sur if `if', percentiles(50) 
					local y2 = r(r1)
					post binscat (`x') (`y1') (`y2') (`se') (`i')
				}
			}
			if `i'==3 { // municipality
				cap drop bin
				local bins = 10
				xtile bin =	temp_reg if !mi(temp_reg), nq(`bins')
				forval b = 1/`bins'  { 
					local if "bin==`b'"
					_pctile temp_sur if `if', nq(100)
					replace temp_sur=r(r`w1') if `if' & temp_sur<r(r`w1')
					replace temp_sur=r(r`w2') if `if' & temp_sur>r(r`w2') & !mi(temp_sur)
					sum temp_reg if `if', meanonly	
					local x = r(mean)
					qui reg temp_sur if `if', robust
					local y1 = _b[_cons]
					local se = _se[_cons]
					_dstpctile temp_sur if `if', percentiles(50) 
					local y2 = r(r1)
					post binscat (`x') (`y1') (`y2') (`se') (`i')
				}
			}
			if `i'==4 { // education
				forval b = 1/6  { 
					local if "edu_sur==`b'"
					_pctile temp_sur if `if', nq(100)
					replace temp_sur=r(r`w1') if `if' & temp_sur<r(r`w1')
					replace temp_sur=r(r`w2') if `if' & temp_sur>r(r`w2') & !mi(temp_sur)
					sum temp_reg if `if', meanonly	
					local x = r(mean)
					qui reg temp_sur if `if', robust
					local y1 = _b[_cons]
					local se = _se[_cons]
					_dstpctile temp_sur if `if', percentiles(50) 
					local y2 = r(r1)
					post binscat (`x') (`y1') (`y2') (`se') (`i')
				}
			}
			if `i'==5 { // sector
				forval b = 1/10  { 
					local if "sec_sur==`b'"
					_pctile temp_sur if `if', nq(100)
					replace temp_sur=r(r`w1') if `if' & temp_sur<r(r`w1')
					replace temp_sur=r(r`w2') if `if' & temp_sur>r(r`w2') & !mi(temp_sur)
					sum temp_reg if `if', meanonly	
					local x = r(mean)
					qui reg temp_sur if `if', robust
					local y1 = _b[_cons]
					local se = _se[_cons]
					_dstpctile temp_sur if `if', percentiles(50) 
					local y2 = r(r1)
					post binscat (`x') (`y1') (`y2') (`se') (`i')
				}	
			}
		}	
		cap postclose binscat
				
		* Figures
		if `p'==50 {
			preserve
				use "$postfiles\binscat.dta", clear
				gen 	axis=200  if _n==1
				replace axis=650 if _n==2
				twoway	(line axis axis, lc(gs10) lp(dash)) ///
					(scatter y1 x if c==1, ms(o)  mc(black)) ///
					(scatter y1 x if c==2, ms(+)  mc(cranberry)) ///
					(scatter y1 x if c==3, ms(x)  mc(navy)) ///
					(scatter y1 x if c==4, ms(sh) mc(green)) ///
					(scatter y1 x if c==5, ms(th) mc(purple)), ///
					$layout xsize(20) ysize(20)  ///
					ylabel(200(100)650, nogrid labsize(small)) xlabel(200(100)650, labsize(small)) ///
					xtitle("Actual P50 of reference group (1000 DKK)") ytitle("Perceived P50 of reference group (1000 DKK)") ///
					legend(r(5) order(2 3 4 5 6) label(2 "Cohort") label(3 "Gender") label(4 "Municipality") label(5 "Education") label(6 "Sector") ring(0) pos(11) size(small)) ///
					name(fig50, replace)
			restore
		}
		if `p'==95 {
			preserve
				use "$postfiles\binscat.dta", clear
				gen 	axis=450  if _n==1
				replace axis=1700 if _n==2
				gen h = y1+1.96*se
				gen l = y1-1.96*se
				twoway	(line axis axis, lc(gs10) lp(dash)) ///
					(scatter y1 x if c==1, ms(o)  mc(black)) ///
					(scatter y1 x if c==2, ms(+)  mc(cranberry)) ///
					(scatter y1 x if c==3, ms(x)  mc(navy)) ///
					(scatter y1 x if c==4, ms(sh) mc(green)) ///
					(scatter y1 x if c==5, ms(th) mc(purple)), ///
					$layout xsize(20) ysize(20)  ///
					ylabel(500(200)1700, nogrid labsize(small)) xlabel(500(200)1700, labsize(small)) ///
					xtitle("Actual P95 of reference group (1000 DKK)") ytitle("Perceived P95 of reference group (1000 DKK)") ///
					legend(r(5) order(2 3 4 5 6) label(2 "Cohort") label(3 "Gender") label(4 "Municipality") label(5 "Education") label(6 "Sector") ring(0) pos(11) size(small)) ///
					name(fig95, replace)
			restore
		}
	}	
	
	graph export "$figs\Figure6A.pdf", replace name(fig50)
	graph export "$figs\Figure6B.pdf", replace name(fig95)
	graph close
	

* FIGURE 7
	
	foreach x in coh sex mun edu sec { 
		cap drop temp1_`x'
		cap drop temp2_`x'
		cap drop temp3_`x'
		cap drop temp4_`x'
		cap drop temp5_`x'
		cap drop temp6_`x'
		gen temp1_`x' = inc_reg/1000
		gen temp2_`x' = .
		gen temp3_`x' = p50_`x'_sur/1000
		gen temp4_`x' = .
		gen temp5_`x' = p95_`x'_sur/1000
		gen temp6_`x' = .
		levelsof `x'_sur, local(refs)	// Self identified group, i.e., 0 and 1 for women and men. 
		/*
		We want to plot the demeaned variables against each other within a 500.000 DKK band. 
		Within the band, we want the curves to intersect at (0,0) to compare the slopes. 
		Using observation outside the band shifts the curves away from (0,0). 
		Therefore, we 
			1. Calculate the average income, A(1).
			2. Find the observations in the interval from 250.000 below A(1) to 250.000 above A(1).
			3. Calculate the average income for these observations, A(2). 
			4. Find the observations in the interval from 250.000 below A(2) to 250.000 above A(2). 
			5. Repeat 3. and 4. until A(X)~=A(X-1)
		*/
		foreach r in `refs' {
			local if "if `x'_sur==`r'"
			sum temp1_`x' `if'			
			local avg = r(mean)			
			local lo = `avg'-250
			local hi = `avg'+250
			local i = 2
			while `i' > 1 {
				local avg_old = `avg'
				sum temp1_`x' `if' & temp1_`x'>`lo' & temp1_`x'<`hi',meanonly
				local avg = r(mean)
				local lo = `avg'-250
				local hi = `avg'+250
				local i = abs(`avg_old'-`avg')
			}
			sum temp1_`x' `if' & temp1_`x'>`lo' & temp1_`x'<`hi'
			replace temp2_`x' = temp1_`x' - r(mean) `if' & temp1_`x'>`lo' & temp1_`x'<`hi'
			local if "if `x'_sur==`r' & !mi(temp2_`x')"
			qui sum temp3_`x' `if', d
			replace temp3_`x'=r(p5)  `if' & temp3_`x'<r(p5)  & !mi(temp3_`x')
			replace temp3_`x'=r(p95) `if' & temp3_`x'>r(p95) & !mi(temp3_`x')
			sum temp3_`x' `if', meanonly
			replace temp4_`x' = temp3_`x' - r(mean) `if'
			qui sum temp5_`x' `if', d
			replace temp5_`x'=r(p5)  `if' & temp5_`x'<r(p5)  & !mi(temp5_`x')
			replace temp5_`x'=r(p95) `if' & temp5_`x'>r(p95) & !mi(temp5_`x')
			sum temp5_`x' `if', meanonly
			replace temp6_`x' = temp5_`x' - r(mean) `if'
		}
	}	

	twoway 	(lpoly temp4_coh temp2_coh, deg(1) bw(100) lp(solid)     lc(black)) ///
			(lpoly temp4_sex temp2_sex, deg(1) bw(100) lp(dash)      lc(cranberry)) ///
			(lpoly temp4_mun temp2_mun, deg(1) bw(100) lp(longdash)  lc(navy)) ///
			(lpoly temp4_edu temp2_edu, deg(1) bw(100) lp(shortdash) lc(green)) ///
			(lpoly temp4_sec temp2_sec, deg(1) bw(100) lp(dash_dot)  lc(purple)), ///
		$layout xsize(20) ysize(20)  ///
		ylabel(-100(50)100, nogrid labsize(small)) xlabel(-200(100)200, labsize(small)) ///
		xtitle("Actual income demeaned within group (1000 DKK)") ytitle("Perceived P50 in reference group" "demeaned within group (1000 DKK)") ///
		legend(ring(0) pos(11) label(1 "Cohort") label(2 "Gender") label(3 "Municipality") label(4 "Education") label(5 "Sector") r(5)) ///
		yline(0, lp(dash) lc(gs8)) ///
		name(fig1, replace)
	twoway 	(lpoly temp6_coh temp2_coh, deg(1) bw(100) lp(solid)     lc(black)) ///
			(lpoly temp6_sex temp2_sex, deg(1) bw(100) lp(dash)      lc(cranberry)) ///
			(lpoly temp6_mun temp2_mun, deg(1) bw(100) lp(longdash)  lc(navy)) ///
			(lpoly temp6_edu temp2_edu, deg(1) bw(100) lp(shortdash) lc(green)) ///
			(lpoly temp6_sec temp2_sec, deg(1) bw(100) lp(dash_dot)  lc(purple)), ///
		$layout xsize(20) ysize(20)  ///
		ylabel(-200(100)200, nogrid labsize(small)) xlabel(-200(100)200, labsize(small)) yscale(range(-250 250)) ///
		xtitle("Actual income demeaned within group (1000 DKK)") ytitle("Perceived P95 in reference group" "demeaned within group (1000 DKK)") ///
		legend(ring(0) pos(11) label(1 "Cohort") label(2 "Gender") label(3 "Municipality") label(4 "Education") label(5 "Sector") r(5)) ///
		yline(0, lp(dash) lc(gs8)) ///
		name(fig2, replace)
		
	graph export "$figs\Figure7A.pdf", replace name(fig1)
	graph export "$figs\Figure7B.pdf", replace name(fig2)
	graph close
	
* NUMBERS IN TEXT: Footnote 21
	
	* Test
	cap drop original
	expand 5, gen(original)
	sort pnr original
	cap drop n
	gen n=1 if pnr!=pnr[_n-1]
	replace n=n[_n-1]+1 if pnr==pnr[_n-1]
	cap drop temp_x
	gen 	temp_x = .
	replace temp_x = temp2_coh if n==1
	replace temp_x = temp2_sex if n==2
	replace temp_x = temp2_mun if n==3
	replace temp_x = temp2_edu if n==4
	replace temp_x = temp2_sec if n==5
	cap drop temp_y1
	gen 	temp_y1 = .
	replace temp_y1 = temp4_coh if n==1
	replace temp_y1 = temp4_sex if n==2
	replace temp_y1 = temp4_mun if n==3
	replace temp_y1 = temp4_edu if n==4
	replace temp_y1 = temp4_sec if n==5
	cap drop temp_y2
	gen 	temp_y2 = .
	replace temp_y2 = temp6_coh if n==1
	replace temp_y2 = temp6_sex if n==2
	replace temp_y2 = temp6_mun if n==3
	replace temp_y2 = temp6_edu if n==4
	replace temp_y2 = temp6_sec if n==5
	reg	temp_y1 i.n##c.temp_x, vce(cluster pnr)	
	
	keep if original==0
	drop original

* FIGURE 8

	cap drop axis
	gen 	axis=0   if _n==1
			replace axis=100 if _n==2
	cap drop miss1 
	cap drop miss2
	cap drop touse
	egen miss1 = rowmiss(position_coh_sur position_sex_sur position_mun_sur position_edu_sur position_sec_sur)
	egen miss2 = rowmiss(position_coh_reg position_sex_reg position_mun_reg position_edu_reg position_sec_reg)
	gen touse = (miss1==0 & miss2==0)
	
	* Panel A
	twoway	(line  axis axis, lc(gs10)   lp(dash) ) 													///
			(lpoly position_coh_sur position_per_coh_reg, deg(1) bw(10) lp(solid)     lc(black))		///
			(lpoly position_sex_sur position_per_sex_reg, deg(1) bw(10) lp(dash)      lc(cranberry)) 	///
			(lpoly position_mun_sur position_per_mun_reg, deg(1) bw(10) lp(longdash)  lc(navy))			///
			(lpoly position_edu_sur position_per_edu_reg, deg(1) bw(10) lp(shortdash) lc(green))		///
			(lpoly position_sec_sur position_per_sec_reg, deg(1) bw(10) lp(dash_dot)  lc(purple)),		///
				$layout xsize(20) ysize(20) 														///
				xtitle("Actual position within reference group ") 									///
				ytitle("Perceived position within reference group") 								///
				xlabel(, labsize(small)) ylabel(, labsize(small) nogrid) 							///
				legend( 																			///
					label(1 "45 degree line") 														///		
					label(2 "Cohort") 																///
					label(3 "Gender") 																///
					label(4 "Municipality") 														///
					label(5 "Education") 															///
					label(6 "Sector") 																///
					r(6) ring(0) pos(5) bmargin(medium) size(small) order(2 3 4 5 6 1)				///
				) 																					///
				name(fig1, replace) 	
	
	* Panel B
	twoway	(lpoly position_per_coh_d position_coh_reg, deg(1) bw(10) lp(solid)     lc(black))		///
			(lpoly position_per_sex_d position_coh_reg, deg(1) bw(10) lp(dash)      lc(cranberry)) 	///
			(lpoly position_per_mun_d position_coh_reg, deg(1) bw(10) lp(longdash)  lc(navy))		///
			(lpoly position_per_edu_d position_coh_reg, deg(1) bw(10) lp(shortdash) lc(green))		///
			(lpoly position_per_sec_d position_coh_reg, deg(1) bw(10) lp(dash_dot)  lc(purple)),	///
				$layout xsize(20) ysize(20) 													///
				xtitle("Actual cohort position") 												///
				ytitle("Perceived - actual position within reference group") 					///
				xlabel(, labsize(small)) ylabel(, labsize(small) nogrid) 						///
				yline(0, lp(dash) lc(gs10))														///
				legend( 																		///
					label(1 "Cohort") 															///
					label(2 "Gender") 															///
					label(3 "Municipality") 													///
					label(4 "Education") 														///
					label(5 "Sector") 															///
					r(5) ring(0) pos(1) bmargin(medium) size(small) order(1 2 3 4 5)			///
				) 																				///
				name(fig2, replace) title()
				
	graph export "$figs\Figure8A.pdf", replace name(fig1)
	graph export "$figs\Figure8B.pdf", replace name(fig2)	
	graph close
	
* NUMBERS IN TEXT: Footnote 23

	* Test
	cap drop original
	expand 5, gen(original)
	sort pnr original
	cap drop n
	gen n=1 if pnr!=pnr[_n-1]
	replace n=n[_n-1]+1 if pnr==pnr[_n-1]
	cap drop temp_position_sur 
	gen 	temp_position_sur = .
	replace temp_position_sur = position_coh_sur if n==1
	replace temp_position_sur = position_sex_sur if n==2
	replace temp_position_sur = position_mun_sur if n==3
	replace temp_position_sur = position_edu_sur if n==4
	replace temp_position_sur = position_sec_sur if n==5
	cap drop temp_position_reg 
	gen 	temp_position_reg = .
	replace temp_position_reg = position_coh_reg 	 if n==1
	replace temp_position_reg = position_sex_reg 	 if n==2
	replace temp_position_reg = position_per_mun_reg if n==3
	replace temp_position_reg = position_per_edu_reg if n==4
	replace temp_position_reg = position_per_sec_reg if n==5
	reg	temp_position_sur i.n i.temp_position_reg if inrange(temp_position_reg,20,40), vce(cluster pnr)	
	keep if original==0
	drop original

* FIGURE 9 

	* Schoolmates
	cap postclose binscat
	postfile binscat x y1 y2 y3 n1 n2 cat using "$postfiles\binscat.dta", replace
	cap drop bin
	local n_bins=25
	xtile bin = position_sch_reg if !mi(position_sch_sur) & school_type=="Grundskole", nq(`n_bins')
	count if !mi(position_sch_sur) & school_type=="Grundskole"
	levelsof bin, local(bin)
	foreach b in `bin'  { 
		sum position_sch_reg if bin==`b', meanonly
		loc x = r(mean)
		qui sum position_sch_sur if bin==`b', d
		loc y1 = r(mean)
		loc n1 = r(N)
		_dstpctile position_sch_sur if bin==`b', percentiles(50)
		loc y2 = r(r1)
		qui sum position_sch_sur if bin==`b' & inrange(n_school_r,-10,10)
		loc y3 = r(mean)
		loc n2 = r(N)
		post binscat (`x') (`y1') (`y2') (`y3') (`n1') (`n2') (1)
	}	
	* Co-workers
	cap drop bin
	local n_bins=27 // to generate 25 bins
	xtile bin = position_wor2_reg if !mi(position_wor_sur), nq(`n_bins')
	levelsof bin, local(bin)
	foreach b in `bin'  { 
		qui sum position_wor2_reg if bin==`b', meanonly
		loc x = r(mean)
		qui sum position_wor_sur  if bin==`b', d
		loc y1 = r(mean)
		loc n1 = r(N)
		_dstpctile position_wor_sur  if bin==`b', percentiles(50) 
		loc y2 = r(r1)
		qui sum position_wor_sur  if bin==`b' & inrange(n_work_r,-10,10)
		loc y3 = r(mean)
		loc n2 = r(N)
		post binscat (`x') (`y1') (`y2') (`y3') (`n1') (`n2') (2)
	}
	* Neighbors
	cap drop bin
	local n_bins=27 // to generate 25 bins
	xtile bin = position_nei_reg if !mi(position_nei_sur), nq(`n_bins')
	levelsof bin, local(bin)
	foreach b in `bin'  {
		qui sum position_nei_reg if bin==`b', meanonly
		loc x = r(mean)
		qui sum position_nei_sur if bin==`b', d
		loc y1 = r(mean)
		loc n1 = r(N)
		_dstpctile position_nei_sur if bin==`b', percentiles(50)
		loc y2 = r(r1)
		qui sum position_nei_sur if bin==`b' & inrange(n_neighbors_r,-10,10)
		loc y3 = r(mean)
		loc n2 = r(N)
		post binscat (`x') (`y1') (`y2') (`y3') (`n1') (`n2') (3)
	}
	postclose binscat 
	
	*Figures
	preserve
		use "$postfiles\binscat.dta", clear
		sum n1 n2
		gen axis=0 if _n==1
		replace axis=100 if _n==2
		twoway	(line axis axis, lc(gs10) lp(dash)) ///
				(scatter y1 x if cat==1, mc(cranberry) ms(o)), ///
				$layout xsize(20) ysize(20)  ///
				ylabel(0(20)100, nogrid labsize(small)) xlabel(0(20)100, labsize(small)) ///
				xtitle("Actual position within schoolmates") ytitle("Perceived position within schoolmates") ///
				legend(off) ///
				xmtick(0(10)100) ymtick(0(10)100) ///
				name(fig1, replace)
		twoway	(line axis axis, lc(gs10) lp(dash)) ///
				(scatter y1 x if cat==2, mc(cranberry) ms(o)), ///
				$layout xsize(20) ysize(20)  ///
				ylabel(0(20)100, nogrid labsize(small)) xlabel(0(20)100, labsize(small)) ///
				xtitle("Actual position within co-workers") ytitle("Perceived position within co-workers") ///
				legend(off) ///
				xmtick(0(10)100) ymtick(0(10)100) ///
				name(fig3, replace)	
		twoway	(line axis axis, lc(gs10) lp(dash)) ///
				(scatter y1 x if cat==3, mc(cranberry) ms(o)), ///
				$layout xsize(20) ysize(20)  ///
				ylabel(0(20)100, nogrid labsize(small)) xlabel(0(20)100, labsize(small)) ///
				xtitle("Actual position within neighbors") ytitle("Perceived position within neighbors") ///
				legend(off) ///
				xmtick(0(10)100) ymtick(0(10)100) ///
				name(fig5, replace)
	restore
	
	graph export "$figs\Figure9A.pdf", replace name(fig3)			
	graph export "$figs\Figure9B.pdf", replace name(fig5)
	graph export "$figs\Figure9C.pdf", replace name(fig1)
	graph close
	
* NUMBERS IN TEXT: Footnote 24

	* Test
	cap drop original
	expand 3, gen(original)
	sort pnr original
	cap drop n
	gen n=1 if pnr!=pnr[_n-1]
	replace n=n[_n-1]+1 if pnr==pnr[_n-1]
	cap drop temp_position_sur 
	gen 	temp_position_sur = .
	replace temp_position_sur = round(position_sch_sur) if n==1
	replace temp_position_sur = round(position_wor_sur) if n==2
	replace temp_position_sur = round(position_nei_sur) if n==3
	cap drop temp_position_reg 
	gen 	temp_position_reg = .
	replace temp_position_reg = round(position_sch_reg) 	if n==1
	replace temp_position_reg = round(position_wor2_reg) 	if n==2
	replace temp_position_reg = round(position_nei_reg) 	if n==3
	reg	temp_position_sur b2.n i.temp_position_reg if inrange(temp_position_reg,20,40), vce(cluster pnr)
	keep if original==0
	drop original

* FIGURE 10

	* Generate random number from 0 to 100 to assign indicators to observations with missing information. 
	set seed 2021
	cap drop  temp_random 
	gen temp_random = runiform()*100
	
	* High-income partner indicator
	cap drop temp_partner_inc
	gen temp_partner_inc = (!mi(inc_efalle) & (inc_efalle/inc_reg)>1.25)
	
	* Vocational occupation indicator
	cap drop temp_disco
	gen temp_disco = substr(disco_kode,1,1)
	destring temp_disco, replace
	cap label drop disco1 
	label define disco1 1 "Ledelsesarbejde" 2 "Arbejde der forudsætter viden på højeste niveau" 3 "Arbejde der forudsætter viden på mellemniveau" 4 " Almindeligt kontor- og kundeservicearbejde" 5 "Service- og salgsarbejde" 6 "Arbejde indenfor landbrug, skovbrug og fiskeri" 7 "Håndværkspræget arbejde" 8 "Operatør- og monteringsarbejde" 9 "Andet manuelt arbejde" 0 "Militært arbejde"
	label values temp_disco disco1
	cap drop temp_occupation
	gen 	temp_occupation = 1 if mi(temp_disco)
	replace temp_occupation = 2 if temp_disco==1
	replace temp_occupation = 3 if temp_disco==2 | temp_disco==3
	replace temp_occupation = 4 if temp_disco==4 | temp_disco==5 | temp_disco==6 | temp_disco==7 | temp_disco==8 | temp_disco==9 | temp_disco==0
	* Randomly allocate observations with missing occupations information and observations on managers to vocational/not vocational.
	tab temp_occupation if temp_occupation>2 // 3 (63.85%), 4 (36.15%)
	replace temp_occupation = 3 if (temp_occupation==1 | temp_occupation==2) & temp_random< 63.85
	replace temp_occupation = 4 if (temp_occupation==1 | temp_occupation==2) & temp_random>=63.85
	tab temp_occupation
	replace temp_occupation = temp_occupation-3
	
	* Private sector indicator
	cap drop temp_sector
	gen temp_sector=1 if mi(private_sector)
	replace temp_sector=2 if private_sector==0
	replace temp_sector=3 if private_sector==1
	* Randomly allocate observations with missing sector information to each group.
	tab temp_sector if temp_sector>1
	replace temp_sector = 2 if temp_sector==1 & temp_random< 34.15
	replace temp_sector = 3 if temp_sector==1 & temp_random>=34.15
	tab temp_sector
	replace temp_sector = temp_sector-2
	
	* High-income father indicator
	cap drop temp_father 
	gen temp_father = 0
	replace temp_father = 1 if inrange(position_fat_reg,76,100)
	
	* Longer education indicator
	cap drop temp_edu
	gen temp_edu = 0
	replace temp_edu = 1 if edu_reg==5 | edu_reg==6
	
	* Copenhagen area indicator
	cap drop temp_cph
	gen temp_cph = 0
	replace temp_cph = 1 if reg==85
	
	* Outcomes
	local nq = 4
	
	cap drop temp
	xtile temp = abs(position_coh_d), n(`nq')
	tab position_coh_d temp
	
	cap drop accurate_own
	gen accurate_own = (temp==1)
	cap drop inaccurate_own
	gen inaccurate_own = (temp==`nq')
	cap drop positive_own
	gen positive_own = (position_coh_d>=0)
	
	cap drop temp
	xtile temp = abs(p50_coh_r), n(`nq')
	tab p50_coh_r temp
	
	cap drop accurate_p50
	gen accurate_p50 = (temp==1)
	cap drop inaccurate_p50
	gen inaccurate_p50 = (temp==`nq')
	cap drop positive_p50
	gen positive_p50 = (p50_coh_r>=0)
	
	cap drop temp
	xtile temp = abs(p95_coh_r), n(`nq')
	tab p95_coh_r temp
	
	cap drop accurate_p95
	gen accurate_p95 = (temp==1)
	cap drop inaccurate_p95
	gen inaccurate_p95 = (temp==`nq')
	cap drop positive_p95
	gen positive_p95 = (p95_coh_r>=0)
	
	cap postclose coef
	postfile coef x y se panel outcome n using "$postfiles\coef", replace

	local regressors 	"i.position_coh_reg"
	
	local i = 0
	foreach x in male temp_cph temp_edu temp_sector temp_occupation temp_partner_inc temp_father right {
		
		local ++i
		
		qui reg inaccurate_own `x' `regressors', robust
		post coef (`i') (_b[`x']) (_se[`x']) (1) (1) (e(N))
		
		qui reg accurate_own `x' `regressors', robust
		post coef (`i') (_b[`x']) (_se[`x']) (2) (1) (e(N))
		
		qui reg positive_own `x' `regressors', robust
		post coef (`i') (_b[`x']) (_se[`x']) (3) (1) (e(N))
		
		local ++i
		
		qui reg inaccurate_p50 `x' `regressors', robust
		post coef (`i') (_b[`x']) (_se[`x']) (1) (2) (e(N))
		 
		qui reg accurate_p50 `x' `regressors', robust
		post coef (`i') (_b[`x']) (_se[`x']) (2) (2) (e(N))
		
		qui reg positive_p50 `x' `regressors', robust
		post coef (`i') (_b[`x']) (_se[`x']) (3) (2) (e(N))
		
		local ++i
		
		qui reg inaccurate_p95 `x' `regressors', robust
		post coef (`i') (_b[`x']) (_se[`x']) (1) (3) (e(N))
		
		qui reg accurate_p95 `x' `regressors', robust
		post coef (`i') (_b[`x']) (_se[`x']) (2) (3) (e(N))
				
		qui reg positive_p95 `x' `regressors', robust
		post coef (`i') (_b[`x']) (_se[`x']) (3) (3) (e(N))
		
		local ++i
	}
	cap postclose coef
			
			
	preserve
		
		use "$postfiles\coef", clear
		
		sum n
		
		replace x = -x
		
		gen h = y+1.96*se
		gen l = y-1.96*se		
		
		replace y = y+0.25 if panel==2
		replace y = y+0.5  if panel==3
		replace y = y+0.75 if panel==4
		replace h = h+0.25 if panel==2
		replace h = h+0.5  if panel==3
		replace h = h+0.75 if panel==4
		replace l = l+0.25 if panel==2
		replace l = l+0.5  if panel==3
		replace l = l+0.75 if panel==4
		
		twoway 	(dot y x    if panel==1 & outcome==1, horizontal ms(O) mc(cranberry) ndot(0))	///
				(rcap h l x if panel==1 & outcome==1, horizontal       lc(cranberry)) 			///
				(dot y x    if panel==1 & outcome==2, horizontal ms(S) mc(navy)      ndot(0)) 	///
				(rcap h l x if panel==1 & outcome==2, horizontal       lc(navy)) 				///
				(dot y x    if panel==1 & outcome==3, horizontal ms(T) mc(black)     ndot(0)) 	///
				(rcap h l x if panel==1 & outcome==3, horizontal       lc(black)) 				///
				(dot y x    if panel==2 & outcome==1, horizontal ms(O) mc(cranberry) ndot(0)) 	///
				(rcap h l x if panel==2 & outcome==1, horizontal       lc(cranberry)) 			///
				(dot y x    if panel==2 & outcome==2, horizontal ms(S) mc(navy)      ndot(0)) 	///
				(rcap h l x if panel==2 & outcome==2, horizontal       lc(navy)) 				///
				(dot y x    if panel==2 & outcome==3, horizontal ms(T) mc(black)     ndot(0)) 	///
				(rcap h l x if panel==2 & outcome==3, horizontal       lc(black)) 				///
				(dot y x    if panel==3 & outcome==1, horizontal ms(O) mc(cranberry) ndot(0)) 	///
				(rcap h l x if panel==3 & outcome==1, horizontal       lc(cranberry)) 			///
				(dot y x    if panel==3 & outcome==2, horizontal ms(S) mc(navy)      ndot(0)) 	///
				(rcap h l x if panel==3 & outcome==2, horizontal       lc(navy)) 				///
				(dot y x    if panel==3 & outcome==3, horizontal ms(T) mc(black)     ndot(0)) 	///
				(rcap h l x if panel==3 & outcome==3, horizontal       lc(black)), 				///
					$layout xline(0 0.25 0.5, lp(dash) lc(gs8)) ///
					ytitle("") xtitle(" " "Estimated effects in percentage points points") xsize(20) ysize(10)  ///
					legend(pos(6) order(1 3 5) r(1) label(1 "Own position") label(3 "P50") label(5 "P95") region(lwidth(none))) ///
					xmlabel(-0.05 "-5" 0 "0" 0.05 "5" 0.2 "-5" 0.25 "0" 0.3 "5" 0.45 "-5" 0.5 "0" 0.55 "5" , labsize(small)) /// 
					xlabel(0 "25% most inaccurate" 0.25 "25% most accurate" 0.5 "Positive misperception" , labgap(medium)) /// 
					ylabel( 								///
						-2 	"Male (=1)"						///
						-6  "Copenhagen area (=1)"			///
						-10	"Longer education (=1)" 		///
						-14	"Private sector (=1)"			///
						-18	"Vocational occupation (=1)"	///
						-22	"High-income partner (=1)"		///
						-26	"High-income father (=1)"		///
						-30	"Right wing (=1)" 				///
						, angle(horizontal) nogrid 			///
					)
						
	restore	
	
	graph export "$figs/Figure10.pdf", replace
	graph close

* FIGURE 11

	local nq = 4

	* Outcomes: Indicators for accuracy, inaccuracy and direction of misperceptions for each small reference group. 
	cap drop temp
	xtile temp = abs(position_sch_d) if n_school_reg>=10, n(`nq')
	sum position_sch_d if temp==1
	
	cap drop accurate_sch
	gen accurate_sch = (temp==1) if n_school_reg>=10 & !mi(temp)
	cap drop inaccurate_sch
	gen inaccurate_sch = (temp==`nq') if n_school_reg>=10 & !mi(temp)
	cap drop positive_sch
	gen positive_sch = (position_sch_d>=0) if n_school_reg>=10 & !mi(temp)
	
	cap drop temp
	xtile temp = abs(position_nei_d) if n_neighbors_reg>=10, n(`nq')
	sum position_nei_d if temp==1
	
	cap drop accurate_nei
	gen accurate_nei = (temp==1) if n_neighbors_reg>=10 & !mi(temp)
	cap drop inaccurate_nei
	gen inaccurate_nei = (temp==`nq') if n_neighbors_reg>=10 & !mi(temp)
	cap drop positive_nei
	gen positive_nei = (position_nei_d>=0) if n_neighbors_reg>=10 & !mi(temp)
	
	cap drop temp
	xtile temp = abs(position_wor_d) if n_work_reg>=10, n(`nq')
	sum position_wor_d if temp==1
	
	cap drop accurate_wor
	gen accurate_wor = (temp==1) if n_work_reg>=10 & !mi(temp)
	cap drop inaccurate_wor
	gen inaccurate_wor = (temp==`nq') if n_work_reg>=10 & !mi(temp)
	cap drop positive_wor
	gen positive_wor = (position_wor_d>=0) if n_work_reg>=10 & !mi(temp)

	* Postfile
	cap postclose coef
	postfile coef x y se panel outcome n using "$postfiles\coef", replace
	
	cap drop temp_position*
	gen temp_position_sch = round(position_sch_reg)
	gen temp_position_nei = round(position_nei_reg)
	gen temp_position_wor = round(position_wor2_reg)
	
	cap drop temp_sec_reg
	gen temp_sec_reg = sec_reg
	replace temp_sec_reg=99 if mi(sec_reg) // Create a value for observations with missing sector information. 

	local regressors "i.coh_reg i.sex_reg i.edu_reg i.reg i.temp_sec_reg"
	
	local i = 0
	* Indicators for High IQR in group, Large group, and High-income group
	foreach x in dispersion temp_num temp_p50 {
		
		local ++i
		
		* Schoolmates
		cap drop dispersion
		qui sum schoolmates_dispersion_iqr, d
		gen dispersion = (schoolmates_dispersion_iqr>r(p50)) if !mi(schoolmates_dispersion_iqr)
		
		cap drop temp_num
		qui sum n_school_reg if n_school_reg>=10, d
		gen temp_num = (n_school_reg>r(p50)) if !mi(n_school_reg)
		
		cap drop temp_p50
		qui sum schoolmates_p50, d
		gen temp_p50 = (schoolmates_p50>r(p50)) if !mi(schoolmates_p50)
		
		qui reg inaccurate_sch `x' i.temp_position_sch `regressors' if n_school_reg>=10, robust
		post coef (`i') (_b[`x']) (_se[`x']) (1) (1) (e(N))
		
		qui reg accurate_sch `x' i.temp_position_sch `regressors' if n_school_reg>=10, robust
		post coef (`i') (_b[`x']) (_se[`x']) (2) (1) (e(N))
		
		qui reg positive_sch `x' i.temp_position_sch  `regressors' if n_school_reg>=10, robust
		post coef (`i') (_b[`x']) (_se[`x']) (3) (1) (e(N))
		
		local ++i
		
		* Neighbors
		cap drop dispersion
		qui sum neighbor_dispersion_iqr if n_neighbors_reg>=10 & apartment==0, d
		gen dispersion = (neighbor_dispersion_iqr>r(p50)) if !mi(neighbor_dispersion_iqr) & n_neighbors_reg>=10 & apartment==0
		
		cap drop temp_num
		qui sum n_neighbors_reg if n_neighbors_reg>=10  & apartment==0, d
		gen temp_num = (n_neighbors_reg>r(p50)) if !mi(n_neighbors_reg) & n_neighbors_reg>=10  & apartment==0
		
		cap drop temp_p50
		qui sum neighbor_p50 if n_neighbors_reg>=10  & apartment==0, d
		gen temp_p50 = (neighbor_p50>r(p50)) if !mi(neighbor_p50)
	
		qui reg inaccurate_nei `x' i.temp_position_nei  `regressors' if n_neighbors_reg>=10 & apartment==0, robust
		post coef (`i') (_b[`x']) (_se[`x']) (1) (2) (e(N))
		 
		qui reg accurate_nei `x' i.temp_position_nei `regressors' if n_neighbors_reg>=10 & apartment==0, robust
		post coef (`i') (_b[`x']) (_se[`x']) (2) (2) (e(N))
		
		qui reg positive_nei `x' i.temp_position_nei `regressors' if n_neighbors_reg>=10 & apartment==0, robust
		post coef (`i') (_b[`x']) (_se[`x']) (3) (2) (e(N))
		
		local ++i
		
		* Coworkers 
		cap drop dispersion
		qui sum coworker_dispersion_iqr, d
		gen dispersion = (coworker_dispersion_iqr>r(p50)) if !mi(coworker_dispersion_iqr)
		
		cap drop temp_num
		qui sum n_work_reg if n_work_reg>=10, d
		gen temp_num = (n_work_reg>r(p50)) if !mi(n_work_reg)
		
		cap drop temp_p50
		qui sum coworker_p50, d
		gen temp_p50 = (coworker_p50>r(p50)) if !mi(coworker_p50)

		qui reg inaccurate_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
		post coef (`i') (_b[`x']) (_se[`x']) (1) (3) (e(N))
		
		qui reg accurate_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
		post coef (`i') (_b[`x']) (_se[`x']) (2) (3) (e(N))
				
		qui reg positive_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
		post coef (`i') (_b[`x']) (_se[`x']) (3) (3) (e(N))
		
		local ++i
		
	}
	
	* Indicators for +3 year at same place (same address or same workplace)
	cap drop temp_same
	gen temp_same = (same_address_2016==1 & same_address_2015==1 & same_address_2014==1)
	local x "temp_same"
	
	qui reg inaccurate_nei `x' i.temp_position_nei  `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (13) (_b[`x']) (_se[`x']) (1) (2) (e(N))
	 
	qui reg accurate_nei `x' i.temp_position_nei `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (13) (_b[`x']) (_se[`x']) (2) (2) (e(N))
	
	qui reg positive_nei `x' i.temp_position_nei `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (13) (_b[`x']) (_se[`x']) (3) (2) (e(N))
	
	cap drop temp_same
	gen temp_same = (same_workplace_2016==1 & same_workplace_2015==1 & same_workplace_2014==1)
	local x "temp_same"
	
	qui reg inaccurate_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
	post coef (14) (_b[`x']) (_se[`x']) (1) (3) (e(N))
		
	qui reg accurate_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
	post coef (14) (_b[`x']) (_se[`x']) (2) (3) (e(N))
				
	qui reg positive_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
	post coef (14) (_b[`x']) (_se[`x']) (3) (3) (e(N))
	
	* Long road indicator
	cap drop road
	qui sum vejlgd if n_neighbors_reg>=10 & apartment==0, d
	gen road = (vejlgd>r(p50)) if !mi(vejlgd) & n_neighbors_reg>=10 & apartment==0
	local x "road"
	
	qui reg inaccurate_nei `x' i.temp_position_nei  `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (16) (_b[`x']) (_se[`x']) (1) (2) (e(N))
		 
	qui reg accurate_nei `x' i.temp_position_nei `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (16) (_b[`x']) (_se[`x']) (2) (2) (e(N))
		
	qui reg positive_nei `x' i.temp_position_nei `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (16) (_b[`x']) (_se[`x']) (3) (2) (e(N))
	
	* Higher house position indicator
	cap drop temp 
	gen temp = hou_nei_reg-position_nei_reg if n_neighbors_reg>=10 & apartment==0
	cap drop temp_rank_house
	sum temp if temp>0 & n_neighbors_reg>=10 & apartment==0, d
	gen temp_rank_house = (temp>r(p75)) if n_neighbors_reg>=10 & !mi(temp) & apartment==0
	local x "temp_rank_house"
	
	qui reg inaccurate_nei `x' i.temp_position_nei  `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (18) (_b[`x']) (_se[`x']) (1) (2) (e(N))
		 
	qui reg accurate_nei `x' i.temp_position_nei `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (18) (_b[`x']) (_se[`x']) (2) (2) (e(N))

	qui reg positive_nei `x' i.temp_position_nei `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (18) (_b[`x']) (_se[`x']) (3) (2) (e(N))
	
	* Higher car position indicator
	cap drop temp
	gen temp = car_nei_reg-position_nei_reg if n_neighbors_reg>=10 & apartment==0
	cap drop temp_rank_car
	sum temp if temp>0 & n_neighbors_reg>=10 & apartment==0, d
	gen temp_rank_car = (temp>r(p75)) if n_neighbors_reg>=10 & !mi(temp) & apartment==0
	local x "temp_rank_car"
	
	qui reg inaccurate_nei `x' i.temp_position_nei  `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (20) (_b[`x']) (_se[`x']) (1) (2) (e(N))
		 
	qui reg accurate_nei `x' i.temp_position_nei `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (20) (_b[`x']) (_se[`x']) (2) (2) (e(N))
		
	qui reg positive_nei `x' i.temp_position_nei `regressors' if n_neighbors_reg>=10 & apartment==0, robust
	post coef (20) (_b[`x']) (_se[`x']) (3) (2) (e(N))
	
	* Managerial role indicator 
	cap drop temp_disco
	gen temp_disco = substr(disco_kode,1,1)
	cap drop temp_manager
	gen temp_manager = (temp_disco=="1")
	local x "temp_manager"
	
	qui reg inaccurate_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
	post coef (22) (_b[`x']) (_se[`x']) (1) (3) (e(N))
		
	qui reg accurate_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
	post coef (22) (_b[`x']) (_se[`x']) (2) (3) (e(N))
				
	qui reg positive_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
	post coef (22) (_b[`x']) (_se[`x']) (3) (3) (e(N))
	
	* High unionization rate indicator
	cap drop temp_union
	gen temp_union = (unionization_rate>0.5)
	local x "temp_union"
	
	qui reg inaccurate_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
	post coef (24) (_b[`x']) (_se[`x']) (1) (3) (e(N))
		
	qui reg accurate_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
	post coef (24) (_b[`x']) (_se[`x']) (2) (3) (e(N))
				
	qui reg positive_wor `x' i.temp_position_wor `regressors' if n_work_reg>=10, robust
	post coef (24) (_b[`x']) (_se[`x']) (3) (3) (e(N))
	
	cap postclose coef
				
	preserve
		
		use "$postfiles\coef", clear
		
		sum n
		
		replace x = -x
		
		gen h = y+1.96*se
		gen l = y-1.96*se		
		
		replace y = y+0.25 if panel==2
		replace y = y+0.5  if panel==3
		replace y = y+0.75 if panel==4
		replace h = h+0.25 if panel==2
		replace h = h+0.5  if panel==3
		replace h = h+0.75 if panel==4
		replace l = l+0.25 if panel==2
		replace l = l+0.5  if panel==3
		replace l = l+0.75 if panel==4
		
		twoway 	(dot y x    if panel==1 & outcome==1, horizontal ms(O) mc(cranberry) ndot(0))	///
				(rcap h l x if panel==1 & outcome==1, horizontal       lc(cranberry)) 			///
				(dot y x    if panel==1 & outcome==2, horizontal ms(S) mc(navy)      ndot(0)) 	///
				(rcap h l x if panel==1 & outcome==2, horizontal       lc(navy)) 				///
				(dot y x    if panel==1 & outcome==3, horizontal ms(T) mc(black)     ndot(0)) 	///
				(rcap h l x if panel==1 & outcome==3, horizontal       lc(black)) 				///
				(dot y x    if panel==2 & outcome==1, horizontal ms(O) mc(cranberry) ndot(0)) 	///
				(rcap h l x if panel==2 & outcome==1, horizontal       lc(cranberry)) 			///
				(dot y x    if panel==2 & outcome==2, horizontal ms(S) mc(navy)      ndot(0)) 	///
				(rcap h l x if panel==2 & outcome==2, horizontal       lc(navy)) 				///
				(dot y x    if panel==2 & outcome==3, horizontal ms(T) mc(black)     ndot(0)) 	///
				(rcap h l x if panel==2 & outcome==3, horizontal       lc(black)) 				///
				(dot y x    if panel==3 & outcome==1, horizontal ms(O) mc(cranberry) ndot(0)) 	///
				(rcap h l x if panel==3 & outcome==1, horizontal       lc(cranberry)) 			///
				(dot y x    if panel==3 & outcome==2, horizontal ms(S) mc(navy)      ndot(0)) 	///
				(rcap h l x if panel==3 & outcome==2, horizontal       lc(navy)) 				///
				(dot y x    if panel==3 & outcome==3, horizontal ms(T) mc(black)     ndot(0)) 	///
				(rcap h l x if panel==3 & outcome==3, horizontal       lc(black)), 				///
				 $layout xline(0 0.25 0.5, lp(dash) lc(gs8)) ///
				 ytitle("") xtitle(" " "Estimated effects in percentage points points") xsize(20) ysize(10)  ///
				 legend(pos(6) order(1 3 5) r(1) label(1 "Schoolmates") label(3 "Neighbors") label(5 "Coworkers") region(lwidth(none))) ///
				 xmlabel(-0.05 "-5" 0 "0" 0.05 "5" 0.2 "-5" 0.25 "0" 0.3 "5" 0.45 "-5" 0.5 "0" 0.55 "5", labsize(small)) /// 
				 xlabel(0 "25% most inaccurate" 0.25 "25% most accurate" 0.5 "Positive misperception", labgap(medium)) /// 
				 ylabel( 									///
					-2		"High IQR in group (=1)"		///
					-6		"Large group (=1)"				///
					-10		"High-income group (=1)"		///
					-13.5	"+3 year at same place (=1)"	///
					-16		"Long road (=1)"				///
					-18		"Higher house position (=1)"		///
					-20		"Higher car position (=1)"	///
					-22		"Managerial role (=1)"			///
					-24		"High unionization rate (=1)"	///
					, angle(horizontal) nogrid 				///
				) 
						
	restore	
	
	graph export "$figs/Figure11.pdf", replace		
	graph close
			
							
* TABLE 3

	local qui 			"qui"
	cap drop miss_out 
	egen     miss_out = rowmiss(Q37_coh Q37_sex Q37_mun Q37_edu)
	cap drop miss_x 
	egen     miss_x   = rowmiss(position_coh_d position_sex_d position_mun_d position_edu_d)
	
	* Panel A
	local regressors 	"temp_position temp_misperception"	
	local control 		" "
	
	local i 0
	foreach x in coh sex mun edu sec {
		local ++i
		cap drop temp_position
		cap drop temp_misperception
		gen temp_position      = (position_per_`x'_reg-50)/100
		gen temp_misperception = position_per_`x'_d/100
		local y  "Q37_`x'"
		eststo reg`i': `qui' reg `y' `regressors' `control' if T==0 & miss_out==0 & miss_x==0, robust
	}
	
	esttab reg1 reg2 reg3 reg4 reg5 using "$tabs\Table3.tex", replace fragment ///
		se b(2) nonum keep(`regressors' _cons) noobs nonote   ///
		mgroup("Unfairness of inequality", pattern(1 0 0 0 0) span prefix(\multicolumn{@span}{c}{) suffix(}) end(\cmidrule(lr){2-6})) ///
		mtitles("Cohort" "Gender" "Municipality" "Education" "Sector") ///
		coef(temp_position "Position in group" temp_misperception "Misperception" _cons "Level at P50") ///
		order(_cons temp_position temp_misperception) ///
		refcat(_cons "\multicolumn{6}{l}{\textbf{Panel A}: No controls} \\ %", nolabel) ///
		prehead({\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \begin{tabular}{l*{5}{c}} \hline\hline) 
	* SD
	sum Q37_coh Q37_sex Q37_mun Q37_edu Q37_sec if T==0 & miss_out==0 & miss_x==0
	
	* Panel B
	local regressors 	"temp_position temp_misperception"
	local control 		"i.coh_reg i.sex_reg i.mun_reg i.edu_reg sec_dum1 sec_dum2 sec_dum3 sec_dum4 sec_dum5 sec_dum6 sec_dum7 sec_dum8 sec_dum9 sec_dum10"
	
	local i 0
	foreach x in coh sex mun edu sec {
		local ++i
		cap drop temp_position
		cap drop temp_misperception
		gen temp_position      = (position_per_`x'_reg-50)/100
		gen temp_misperception = position_per_`x'_d/100
		local y  "Q37_`x'"
		eststo reg`i': `qui' reg `y' `regressors' `control' if T==0 & miss_out==0 & miss_x==0, robust
	}
	
	esttab reg1 reg2 reg3 reg4 reg5 using "$tabs\Table3.tex", append fragment ///
		se b(2) nonum keep(`regressors') nonote nomtit   ///
		coef(temp_position "Position in group" temp_misperception "Misperception") ///
		refcat(temp_position "\multicolumn{6}{l}{\textbf{Panel B}: With controls} \\ %", nolabel) ///
		postfoot(\hline\hline \end{tabular}})
	

* TABLE 4
	
	cap drop miss_out
	egen     miss_out = rowmiss(Q37_coh Q37_sex Q37_mun Q37_edu)
	replace  miss_out = miss_out+1 if mi(Q37_sec) & !mi(position_sec_sur)
	cap drop miss_x
	egen     miss_x = rowmiss(position_coh_d position_sex_d position_mun_d position_edu_d)
	replace  miss_x = miss_x+1 if !mi(Q37_sec) & mi(position_sec_sur)
	
	foreach x in sex mun edu sec {
		cap drop Q37_`x'_coh
		gen 	 Q37_`x'_coh = Q37_`x'-Q37_coh
	}
	cap drop Q37_coh_coh
	gen 	 Q37_coh_coh = Q37_coh
	
	local if 	"if miss_out==0 & miss_x==0" 
	
	* Panel A
	local i 0
	foreach x in coh sex mun edu sec {
		local ++i
		cap drop pos_temp
		gen pos_temp = position_per_`x'_reg 
		local regressors	"i.pos_temp T"
		local outcome		"Q37_`x'"
		eststo reg`i': qui reg `outcome' `regressors'  `if', robust
			qui estadd local inc "\checkmark"
			di "`e(N)'"
	}
	
	esttab reg1 reg2 reg3 reg4 reg5 using "$tabs\Table4.tex", replace fragment ///
		b(3) keep(T) se noomit nobase nonum nonote noobs ///
		coef(T "Treatment (=1)")   ///
		mtitles("Cohort" "Gender" "Municipality" "Education" "Sector") ///
		mgroup("Unfairness of inequality" , pattern(1 0 0 0 0) span prefix(\multicolumn{@span}{c}{) suffix(}) end(\cmidrule(lr){2-6})) ///
		refcat(T "\textbf{Panel A}", nolabel) ///
		prehead({\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \begin{tabular}{l*{5}{c}} \hline\hline) 
	
	* Panel B
	local i 0
	foreach x in coh sex mun edu sec {
		local ++i
		cap drop misp_temp
		gen misp_temp = position_per_`x'_d/100
		cap drop positive
		gen positive = (misp_temp>=0)
		cap drop negative
		gen negative = (misp_temp<0)
		cap drop pos_temp
		gen pos_temp = position_per_`x'_reg // 
		cap drop int_pos
		gen int_pos = T*positive
		cap drop int_neg
		gen int_neg = T*negative
		local regressors	"i.pos_temp positive int_pos int_neg"
		local outcome		"Q37_`x'_z"
		eststo reg`i': qui reg `outcome' `regressors' `if', robust
			qui estadd local inc "\checkmark"
			di "`e(N)'"
			local N`i' = `e(N)'
	}
	
	esttab reg1 reg2 reg3 reg4 reg5 using "$tabs\Table4.tex", append fragment ///
		b(3) drop(_cons *.pos_temp) se noomit nobase nonum nonote nomtit noobs ///
		coef(positive "Positive misperception" int_pos "T $\times$ Positive" int_neg "T $\times$ Negative") ///
		refcat(positive "\textbf{Panel B}", nolabel) 
		
	* Panel C
	local i 0
	foreach x in sex mun edu sec {
		local ++i
		cap drop pos_temp
		gen pos_temp = position_per_`x'_reg 
		local regressors	"i.pos_temp T"
		local outcome		"Q37_`x'_coh"
		eststo reg`i': qui reg `outcome' `regressors'  `if', robust
			qui estadd local inc "\checkmark"
			di "`e(N)'"
	}
	
	esttab reg1 reg2 reg3 reg4 using "$tabs\Table4.tex", append fragment ///
		b(3) keep(T) se noomit nobase nonum nonote noobs ///
		coef(T "Treatment (=1)")  /// ///
		mtitles("Gender" "Municipality" "Education" "Sector") ///
		mgroup("Difference in unfairness relative to cohort", pattern(1 0 0 0) span prefix(\multicolumn{@span}{c}{) suffix(}) end(\cmidrule(lr){3-6})) ///
		refcat(T "\textbf{Panel C}", nolabel)  extracol(1) ///
		prehead(\hline) ///
		postfoot(\hline \(N\) & `N1' &  `N2'  &  `N3'  &  `N4'  &  `N5'  \\ Group position FE & \checkmark & \checkmark & \checkmark & \checkmark & \checkmark \\ \hline\hline \end{tabular}}) 
		

* FIGURE 12

	local legend	"r(3) ring(0) symx(*.75) label(1 "20 years ago") label(2 "15 years ago") label(3 "10 years ago") label(4 "5 years ago") label(5 "This year") label(6 "Father") order(5 4 3 2 1 6)"
	cap drop miss*
	egen miss1 = rowmiss(position_1997 position_2002 position_2007 position_2012 position_2017)
	local if "if miss1==0"
	count `if'
	count `if' & T==0
	
	* Panel A
	twoway 	(lpoly Q37_coh position_1997 	`if' & T==0, deg(1) bw(20) lp(dash_dot) 	lc(purple)) 		///
			(lpoly Q37_coh position_2002 	`if' & T==0, deg(1) bw(20) lp(shortdash)	lc(blue))			///
			(lpoly Q37_coh position_2007 	`if' & T==0, deg(1) bw(20) lp(dash) 		lc(green)) 			///
			(lpoly Q37_coh position_2012 	`if' & T==0, deg(1) bw(20) lp(longdash)		lc(orange)) 		///
			(lpoly Q37_coh position_2017 	`if' & T==0, deg(1) bw(20) lp(solid) 		lc(red)) 			///
			(lpoly Q37_coh position_fat_reg	`if' & T==0, deg(1) bw(20) lp(dot) 			lc(black) lw(1)), 	///
				$layout xsize(20) ysize(20) ///
				xtitle("Actual cohort position") ytitle("Unfairness of inequality within cohort") ///
				ylabel(`ylbl', labsize(small) nogrid) xlabel(, labsize(small)) ///
				legend(`legend' pos(7)) ///
				name(fig1, replace)
	
	* Panel B
	twoway 	(lpoly position_coh_sur position_1997 		`if', deg(1) bw(20) lp(dash_dot) 	 lc(purple)) 		///
			(lpoly position_coh_sur position_2002 		`if', deg(1) bw(20) lp(shortdash)	 lc(blue))			///
			(lpoly position_coh_sur position_2007 		`if', deg(1) bw(20) lp(dash) 		 lc(green)) 		///
			(lpoly position_coh_sur position_2012 		`if', deg(1) bw(20) lp(longdash)	 lc(orange)) 		///
			(lpoly position_coh_sur position_2017 		`if', deg(1) bw(20) lp(solid) 		 lc(red)) 			///
			(lpoly position_coh_sur position_fat_reg	`if', deg(1) bw(20) lp(dot) 		 lc(black) lw(1)), 	///
				$layout xsize(20) ysize(20) ///
				xtitle("Actual cohort position") ytitle("Perceived position this year") ///
				ylabel(0(20)100, labsize(small) nogrid) xlabel(0(20)100, labsize(small)) ///
				legend(r(6) ring(0) symx(*.5) label(1 "20 years ago") label(2 "15 years ago") label(3 "10 years ago") label(4 "5 years ago") label(5 "This year") label(6 "Father") order(5 4 3 2 1 6) pos(5)) ///
				name(fig2, replace)
	
			
	graph export "$figs\Figure12A.pdf", replace name(fig1)
	graph export "$figs\Figure12B.pdf", replace name(fig2)
	graph close

* NUMBERS IN TEXT: Footnote 28

	* Test
	cap drop original
	expand 6, gen(original)
	sort pnr original
	cap drop n
	gen n=1 if pnr!=pnr[_n-1]
	replace n=n[_n-1]+1 if pnr==pnr[_n-1]
	cap drop temp_position_reg 
	gen 	temp_position_reg = .
	replace temp_position_reg = position_1997 	 if n==1
	replace temp_position_reg = position_2002 	 if n==2
	replace temp_position_reg = position_2007 	 if n==3
	replace temp_position_reg = position_2012 	 if n==4
	replace temp_position_reg = position_2017 	 if n==5
	replace temp_position_reg = position_fat_reg if n==6
	reg	Q37_coh b5.n##c.temp_position_reg, vce(cluster pnr)	
	keep if original==0
	drop original
	reg	Q37_coh position_fat_reg	
	
* TABLE 5

	cap drop temp_position 
	gen temp_position = position_2008
	
	local control 	"T i.coh_reg i.sex_reg i.mun_reg_2008_imp i.edu_reg_2008_imp sec_dum_2008_*"
	local income	"i.temp_position"
	local qui 		 "qui"
	local m_grp		"mgroup("Cohort position" "Unfairness of inequality" "N" "Affected" , pattern(1 0 1 0 0 0 0 1 1) span prefix(\multicolumn{@span}{c}{) suffix(}) end(\cmidrule(lr){2-3}\cmidrule(lr){4-8}))" 
	local m_tit 	"mtitles("Actual" "Perceived" "Cohort" "Gender" "Mun." "Edu." "Sector" " " "\%")"
	local scal 		""inc08 Pre-shock position FE" "con Controls""
	cap drop miss_out
	egen miss_out = rowmiss(Q37_coh Q37_sex Q37_mun Q37_edu)
	local if		"if miss_out==0 & !mi(temp_position) & T==0"
	local b			"2"
	
	eststo clear
	
	* Unemployment
	local outcomes 		"position_coh_reg position_coh_sur Q37_coh Q37_sex Q37_mun Q37_edu Q37_sec" 
	local models		"reg1 reg2 reg3 reg4 reg5 reg6 reg7 obs sha"
	local regressors 	"unemp_12_17"
	local restriction 	"& unemp_08_11==0 & wf08_17<3 & !mi(Q37_sec)"
	sum 	`regressors' `if' `restriction'
	Nshare 	`regressors'
	
	local i 0
	foreach y in `outcomes' {
		local ++i
		eststo reg`i': `qui' reg `y' `regressors' `income' `control' `if' `restriction', robust
		di "OUTCOME: `y'. N=`e(N)'"
	}
	esttab `models' using "$tabs\Table5.tex", replace fragment ///
		se b(`b') noobs nonum label keep(`regressors') coef(`regressors' "Unemployment") `m_grp' `m_tit' ///
		prehead({\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \begin{tabular}{l*{9}{c}} \hline\hline) ///
		posthead(& (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) \\ \hline)  	
		
	* Disability
	local outcomes 	"position_coh_reg position_coh_sur Q37_coh Q37_sex Q37_mun Q37_edu"
	local models	"reg1 reg2 reg3 reg4 reg5 reg6 obs sha"
	local regressors 	"disab_12_17"
	local restriction 	"& disab_08_11==0"
	sum 	`regressors' `if' `restriction'
	Nshare 	`regressors'
	
	local i 0
	foreach y in `outcomes' {
		local ++i
		eststo reg`i': `qui' reg `y' `regressors' `income' `control' `if' `restriction', robust
		di "OUTCOME: `y'. N=`e(N)'"
	}
	esttab `models' using "$tabs\Table5.tex", append fragment ///
		se b(`b') noobs label nonum keep(`regressors')  nomtit posthead([1em]) coef(`regressors' "Disability") extracol(7)

	* Hospitalization
	local outcomes 	"position_coh_reg position_coh_sur Q37_coh Q37_sex Q37_mun Q37_edu Q37_sec" 
	local models	"reg1 reg2 reg3 reg4 reg5 reg6 reg7 obs sha"
	local regressors 	"healt_12_17"
	local restriction 	"& healt_08_11==0 & !mi(Q37_sec)"
	sum 	`regressors' `if' `restriction'
	Nshare 	`regressors'
	
	local i 0
	foreach y in `outcomes' {
		local ++i
		eststo reg`i': `qui' reg `y' `regressors' `income' `control' `if' `restriction', robust
		di "OUTCOME: `y'. N=`e(N)'"
	}
	esttab `models' using "$tabs\Table5.tex", append fragment ///
		se b(`b') noobs label nonum keep(`regressors')  nomtit posthead([1em]) coef(`regressors' "Hospitalization")

	* Promotion
	local outcomes 	"position_coh_reg position_coh_sur Q37_coh Q37_sex Q37_mun Q37_edu Q37_sec" 
	local models	"reg1 reg2 reg3 reg4 reg5 reg6 reg7 obs sha"
	local regressors 	"manag_12_17"
	local restriction 	"& manag_08_11==0 & !mi(Q37_sec)"
	sum 	`regressors' `if' `restriction'
	Nshare 	`regressors'
	
	local i 0
	foreach y in `outcomes' {
		local ++i
		eststo reg`i': `qui' reg `y' `regressors' `income' `control' `if' `restriction', robust
		di "OUTCOME: `y'. N=`e(N)'"
			`qui' estadd local  inc08 "\checkmark"
			`qui' estadd local  con   "\checkmark"
	}
	
	esttab `models' using "$tabs\Table5.tex", append fragment ///
		se b(`b') noobs label nonum keep(`regressors') sfmt(g) scalar(`scal') posthead([1em]) nomtit coef(`regressors' "Promotion") ///
		postfoot(\hline\hline \end{tabular}})

********************************************************************************